;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "poly-markdown" "20251101.1318"
  "Polymode for markdown-mode."
  '((emacs         "25")
    (polymode      "0.2.2")
    (markdown-mode "2.3"))
  :url "https://github.com/polymode/poly-markdown"
  :commit "2eb00d1d07a9dd5d94c5c12c27714e095b3b142a"
  :revdesc "2eb00d1d07a9"
  :keywords '("emacs"))
